# MISP parser

MISP events collected by the MISPCollectorBot are passed to this parser
for processing. Supported MISP event categories and attribute types are
defined in the SUPPORTED_MISP_CATEGORIES and MISP_TYPE_MAPPING class
constants.
